===============
``xeofs.cross``
===============
Methods that investigate relationships or patterns between variables **across two** distinct datasets.

.. autosummary::
   :toctree: _autosummary
   :template: custom-class-template.rst
   :recursive:

   ~xeofs.cross.CCA
   ~xeofs.cross.MCA
   ~xeofs.cross.RDA
   ~xeofs.cross.CPCCA
   ~xeofs.cross.ComplexCCA
   ~xeofs.cross.ComplexMCA
   ~xeofs.cross.ComplexRDA
   ~xeofs.cross.ComplexCPCCA
   ~xeofs.cross.HilbertCCA
   ~xeofs.cross.HilbertMCA
   ~xeofs.cross.HilbertRDA
   ~xeofs.cross.HilbertCPCCA

------------------------------
Sparse Solutions via Rotation
------------------------------

.. autosummary::
   :toctree: _autosummary
   :template: custom-class-template.rst
   :recursive:

   ~xeofs.cross.MCARotator
   ~xeofs.cross.CPCCARotator
   ~xeofs.cross.ComplexMCARotator
   ~xeofs.cross.ComplexCPCCARotator
   ~xeofs.cross.HilbertMCARotator
   ~xeofs.cross.HilbertCPCCARotator
